@@ -1,7 +1,18 @@
 package Text::ASED;
 
-use File::Copy;
-use POSIX;;
+# Author : $Author: legrady $
+# Date	 : $Date: 2002/04/16 00:12:10 $
+# Version : $Revision: 1.9 $
+# Log	  : $Log: ASED.pm,v $
+# Log	  : Revision 1.9  2002/04/16 00:12:10  legrady
+# Log	  : That version generated syntax errors.
+# Log	  :
+# Log	  : Revision 1.7  2002/04/16 00:56:50  legrady
+# Log	  : Modified version line.
+# Log	  :
+# Log	  : Revision 1.4  2002/04/16 00:36:06  legrady
+# Log	  : Added cvs variables to get version and file.
+# Log	  :
 
 require 5.005_62;
 use strict;
@@ -11,7 +22,7 @@ use Text::Abbrev;
 use Carp;
 
 use vars qw( $VERSION );
-($VERSION = '$Revision: 1.12 $ ') =~ s/[^\d\.]*//g;
+($VERSION = '$Revision: 1.9 $') =~ s/[^\d\.]*//g;
 
 #
 sub true ()	{ 1; }
@@ -93,7 +104,6 @@ sub reuse {
     $self->{used} = false;
     delete $self->{eval};
 }
-
 sub prep {
     my $self = shift;
 
@@ -361,15 +371,8 @@ sub edit {
 	    }
 	}
     }
-
-    #	generate a tempfile name, mark flag for copying back onto original.
-    unless ( $newargs{outfile} ) { 
-	my $name;
-	do {
-	    $name = POSIX::tmpnam();
-	} until ( ! -e $name );
-	
-	$newargs{outfile} = $name;
+    unless ( $newargs{outfile} ) {
+	$newargs{outfile} = "/tmp/$$";
 	$fileflag = true;
     }
 
@@ -388,12 +391,12 @@ sub edit {
 	$self->{eval} .= $code;
 	$self->{eval} .= convert_end_overhead( @_ );
     }
-    print "Running:\n$self->{eval}\n" if ( defined $ENV{DEBUG} );
+#    print "Running:\n$self->{eval}\n";
     unless ( defined eval $self->{eval} ) {
 	die( "$@" );
     }
     $self->{used} = true;
-    copy( $newargs{outfile}, $newargs{infile} ) if $fileflag;
+    rename( "/tmp/$$", $newargs{infile} ) if $fileflag;
     1;
 }
 
